.. all-saltext.vault.states:

_____________
State Modules
_____________

.. currentmodule:: saltext.vault.states

.. autosummary::
    :toctree:

    vault
    vault_db
    vault_pki
    vault_secret
    vault_ssh
